yakumo.neutron.v2.lb.health_monitor.Manager

Package yakumo :: Package neutron :: Package v2 :: Package lb :: Module health_monitor :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for LB Health Monitors in Networking V2 API

Nested Classes | [hide private]
| resource_class Resource class for LB Health Monitors in Networking V2 API

Instance Methods | [hide private]
yakumo.neutron.v2.lb.health_monitor.Resource |
create(self, type=`'``__UNDEF__``'`, http_method=`'``__UNDEF__``'`, url_path=`'``__UNDEF__``'`, expected_codes=`'``__UNDEF__``'`, delay=`'``__UNDEF__``'`, timeout=`'``__UNDEF__``'`, max_retries=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) Create a LB health monitor | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``network``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _json_resource_key = ``'``health_monitor``'``
| _json_resources_key = ``'``health_monitors``'``
| _url_resource_path = ``'``/v2.0/lb/health_monitors``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, type=`'``__UNDEF__``'`, http_method=`'``__UNDEF__``'`, url_path=`'``__UNDEF__``'`, expected_codes=`'``__UNDEF__``'`, delay=`'``__UNDEF__``'`, timeout=`'``__UNDEF__``'`, max_retries=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) | source code
Create a LB health monitor Parameters: `type` (str) - Monitor type ('PING', 'TCP', 'HTTP', or 'HTTPS') `http_method` (str) - HTTP method like 'GET' `url_path` (str) - URL path like '/index.html' `expected_codes` (str) - Expected HTTP response code list separated with comma `delay` (int) - Seconds to start waiting a response `timeout` (int) - Maximum seconds to wait a response `max_retries` (int) - Number of allowed connection failures (up to 10) `is_enabled` (bool) - Monitor is enabled Returns: yakumo.neutron.v2.lb.health_monitor.Resource Created monitor Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('project', 'tenant_id', mapper.Resource('
      project')), ('is_enabled', 'admin_state_up', mapper.Noop), ('pools', '
      pools', mapper.List(mapper.Resource('neutron.lb.pool'))), ('type', 'ty
      pe', mapper.Noop), ('http_method', 'http_method', mapper.Noop), ('url_
      path', 'url_path', mapper.Noop), ('expected_codes', 'expected_codes',
      mapper.Noop), ('delay', 'delay', mapper.Noop), ('timeout', 'timeout',
      mapper.Noop), ('max_retries', 'max_retries', mapper.Noop),]